"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.downlevelCodeWithTsc = void 0;
const typescript_1 = require("typescript");
const path = require("path");
const log = require("../utils/log");
const cache_1 = require("../utils/cache");
/**
 * Base `tsc` `CompilerOptions` shared among various downleveling methods.
 */
const COMPILER_OPTIONS = {
    target: typescript_1.ScriptTarget.ES2015,
    module: typescript_1.ModuleKind.ESNext,
    allowJs: true,
    sourceMap: true,
    importHelpers: true,
    downlevelIteration: true,
    moduleResolution: typescript_1.ModuleResolutionKind.Classic,
};
/**
 * Downlevels a .js file from `ES2015` to `ES2015`. Internally, uses `tsc`.
 */
async function downlevelCodeWithTsc(code, filePath) {
    log.debug(`tsc ${filePath}`);
    const key = cache_1.generateKey(code);
    const result = await cache_1.readCacheEntry(key);
    if (result) {
        return result;
    }
    const compilerOptions = {
        ...COMPILER_OPTIONS,
        mapRoot: path.dirname(filePath),
    };
    const { outputText, sourceMapText } = typescript_1.transpileModule(code, {
        compilerOptions,
    });
    cache_1.saveCacheEntry(key, JSON.stringify({
        code: outputText,
        map: sourceMapText,
    }));
    return {
        code: outputText,
        map: JSON.parse(sourceMapText),
    };
}
exports.downlevelCodeWithTsc = downlevelCodeWithTsc;
//# sourceMappingURL=downlevel-plugin.js.map