"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rollupBundleFile = void 0;
const rollup = require("rollup");
const plugin_node_resolve_1 = require("@rollup/plugin-node-resolve");
const sourcemaps = require("rollup-plugin-sourcemaps");
const commonJs = require("@rollup/plugin-commonjs");
const rollupJson = require("@rollup/plugin-json");
const log = require("../utils/log");
const path = require("path");
/** Runs rollup over the given entry file, writes a bundle file. */
async function rollupBundleFile(opts) {
    log.debug(`rollup (v${rollup.VERSION}) ${opts.entry} to ${opts.dest}`);
    // Create the bundle
    const bundle = await rollup.rollup({
        context: 'this',
        external: moduleId => isExternalDependency(moduleId),
        inlineDynamicImports: false,
        cache: opts.cache,
        input: opts.entry,
        plugins: [
            // @ts-ignore
            rollupJson(),
            // @ts-ignore
            plugin_node_resolve_1.default(),
            // @ts-ignore
            commonJs(),
            // @ts-ignore
            sourcemaps(),
            { transform: opts.transform },
        ],
        onwarn: warning => {
            if (typeof warning === 'string') {
                log.warn(warning);
            }
            else {
                if (warning.code === 'THIS_IS_UNDEFINED') {
                    return;
                }
                log.warn(warning.message);
            }
        },
        preserveSymlinks: true,
        // Disable treeshaking when generating bundles
        // see: https://github.com/angular/angular/pull/32069
        treeshake: false,
    });
    // Output the bundle to disk
    await bundle.write({
        name: opts.moduleName,
        format: 'es',
        file: opts.dest,
        banner: '',
        sourcemap: true,
    });
    return bundle.cache;
}
exports.rollupBundleFile = rollupBundleFile;
function isExternalDependency(moduleId) {
    // more information about why we don't check for 'node_modules' path
    // https://github.com/rollup/rollup-plugin-node-resolve/issues/110#issuecomment-350353632
    if (moduleId.startsWith('.') || moduleId.startsWith('/') || path.isAbsolute(moduleId)) {
        // if it's either 'absolute', marked to embed, starts with a '.' or '/' or is the umd bundle and is tslib
        return false;
    }
    return true;
}
//# sourceMappingURL=rollup.js.map