"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeBundlesTransform = void 0;
const ora = require("ora");
const transform_1 = require("../../graph/transform");
const nodes_1 = require("../nodes");
const rollup_1 = require("../../flatten/rollup");
const downlevel_plugin_1 = require("../../flatten/downlevel-plugin");
const writeBundlesTransform = (options) => transform_1.transformFromPromise(async (graph) => {
    const entryPoint = graph.find(nodes_1.isEntryPointInProgress());
    const { destinationFiles, entryPoint: ngEntryPoint, tsConfig } = entryPoint.data;
    const cache = entryPoint.cache;
    const { fesm2020, fesm2015, esm2020 } = destinationFiles;
    const spinner = ora({
        hideCursor: false,
        discardStdin: false,
    });
    try {
        spinner.start('Generating FESM2020');
        const rollupFESMCache = await rollup_1.rollupBundleFile({
            sourceRoot: tsConfig.options.sourceRoot,
            entry: esm2020,
            moduleName: ngEntryPoint.moduleId,
            dest: fesm2020,
            cache: cache.rollupFESM2020Cache,
        });
        spinner.succeed();
        if (options.watch) {
            cache.rollupFESM2020Cache = rollupFESMCache;
        }
    }
    catch (error) {
        spinner.fail();
        throw error;
    }
    try {
        spinner.start('Generating FESM2015');
        const rollupFESMCache = await rollup_1.rollupBundleFile({
            sourceRoot: tsConfig.options.sourceRoot,
            entry: esm2020,
            moduleName: ngEntryPoint.moduleId,
            dest: fesm2015,
            transform: downlevel_plugin_1.downlevelCodeWithTsc,
            cache: cache.rollupFESM2015Cache,
        });
        spinner.succeed();
        if (options.watch) {
            cache.rollupFESM2015Cache = rollupFESMCache;
        }
    }
    catch (error) {
        spinner.fail();
        throw error;
    }
});
exports.writeBundlesTransform = writeBundlesTransform;
//# sourceMappingURL=write-bundles.transform.js.map