"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveCacheEntry = exports.readCacheEntry = exports.generateKey = void 0;
const findCacheDirectory = require("find-cache-dir");
const os_1 = require("os");
const cacache = require("cacache");
const fs_1 = require("../utils/fs");
const crypto_1 = require("crypto");
const cachePath = findCacheDirectory({ name: 'ng-packagr' }) || os_1.tmpdir();
let ngPackagrVersion;
try {
    ngPackagrVersion = require('../../package.json').version;
}
catch {
    // dev path
    ngPackagrVersion = require('../../../package.json').version;
}
function generateKey(...valuesToConsider) {
    return crypto_1.createHash('sha1').update(ngPackagrVersion).update(valuesToConsider.join(':')).digest('hex');
}
exports.generateKey = generateKey;
async function readCacheEntry(key) {
    const entry = await cacache.get.info(cachePath, key);
    if (entry) {
        return JSON.parse(await fs_1.readFile(entry.path, 'utf8'));
    }
    return undefined;
}
exports.readCacheEntry = readCacheEntry;
async function saveCacheEntry(key, content) {
    await cacache.put(cachePath, key, content);
}
exports.saveCacheEntry = saveCacheEntry;
//# sourceMappingURL=cache.js.map